@@ -16,14 +16,20 @@ class SendDataController:
             try:
                 if processedCoT.modelObject.m_detail.Marti.m_Dest.callsign != '':
                     for client in clientInformationQueue:
-                        if client.modelObject.m_detail.m_Contact.callsign == processedCoT.modelObject.m_detail.Marti.m_Dest.callsign:
-                            sock = client.socket
-                            try:
-                                sock.send(processedCoT.xmlString)
-                            except:
-                                break                    
-                        else:
-                            continue
+                        try:
+                            if client.modelObject.m_detail.m_Contact.callsign == processedCoT.modelObject.m_detail.Marti.m_Dest.callsign:
+                                sock = client.socket
+                                try:
+                                    sock.send(processedCoT.xmlString)
+                                except:
+                                    logger.error('error sending data with marti to client data ' + str(processedCoT.xmlString) + 'error is '+str(e))
+                                    return -1
+                            else:
+                                continue
+                        except Exception as e:
+                            logger.error('error sending data with marti to client within if data is ' + str(processedCoT.xmlString) + 'error is '+str(e))
+                            return -1
+                    return 1
             except:
                 pass
             
@@ -34,19 +40,24 @@ class SendDataController:
                         sock.send(processedCoT.idData.encode())
                         sender.socket.send(client.idData.encode())
                     except:
-                        break
+                        logger.error('error in sending connection data ' + str(processedCoT.idData))
+                        return -1
+                return 1
+
 
             else:
                 for client in clientInformationQueue:
-
                     if client != sender:
+
                         sock = client.socket
                         try:
                             sock.send(processedCoT.xmlString)
                         except Exception as e:
-                            #print(e)
-                            break
+                            logger.error('error in sending of data ' + str(processedCoT.xmlString))
+                            return -1
                     else:
-                        break
+                        continue
+                return 1
         except Exception as e:
-            logger.error(loggingConstants.SENDDATACONTROLLERSENDDATAINQUEUEERROR+str(e))
\ No newline at end of file
+            logger.error(loggingConstants.SENDDATACONTROLLERSENDDATAINQUEUEERROR+str(e))
+            return -1
\ No newline at end of file
